import React, { Component, MouseEvent } from 'react';


type Language = "en" | "es";

type HelloProps = {
  /** Value of the name query parameter. */
  name: string
};

type HelloState = {
  /** Dictates the language of the greeting. */
  lang: Language
};


/** Displays the hello UI. */
export class Hello extends Component<HelloProps, HelloState> {
  constructor(props: HelloProps) {
    super(props);

    this.state = {lang: "en"};
  }

  render = (): JSX.Element => {
    return (
      <div>
        {this.renderGreeting()}
        {this.renderButton()}
      </div>);
  };

  // Returns the greeting UI in the appropriate language.
  renderGreeting = (): JSX.Element => {
    if (this.state.lang === "en") {
      return <p>Hi, {this.props.name}!</p>
    } else {
      return <p>Hola, {this.props.name}!</p>
    }
  };

  // Returns the button UI.
  renderButton = (): JSX.Element => {
    if (this.state.lang === "en") {
      return <button onClick={this.doEspClick}>Español</button>;
    } else {
      return <button onClick={this.doEngClick}>English</button>;
    }
  };

  // Called when the user selects the Español button to translate the greeting
  // from English to Spanish
  doEspClick = (_evt: MouseEvent<HTMLButtonElement>): void => {
    this.setState({lang: "es"});
  };

  // Called when the user selects the English button to translate the greeting
  // from Spanish to English
  doEngClick = (_evt: MouseEvent<HTMLButtonElement>): void => {
    this.setState({lang: "en"});
  };
}
